# typingchecker
Package for checking python typing annotations.

The documentation is available online at:

https://github.com/Olimaol/typingchecker/wiki

### Authors

* Oliver Maith (oliver_maith@gmx.de)


## Installation

From PyPI using pip:

```
pip install typingchecker
```

With downloaded source code; using pip in the top-level directory of the downloaded source code:

```
pip install .
```

or in development mode:

```
pip install -e .
```
